@@ -80,19 +80,6 @@ void ListView::setOpacity(qreal opacity) {
     }
 }
 
-void ListView::setFocus(bool focus) {
-    Q_D(const ListView);
-
-    if ((d->complete) && (focus != this->hasFocus())) {
-        if (focus) {
-            this->setFocus(Qt::OtherFocusReason);
-        }
-        else {
-            this->clearFocus();
-        }
-    }
-}
-
 AnchorLine ListView::left() const {
     Q_D(const ListView);
 
@@ -242,6 +229,9 @@ void ListView::changeEvent(QEvent *event) {
     case QEvent::ParentChange:
         emit parentChanged();
         break;
+    case QEvent::EnabledChange:
+        emit enabledChanged();
+        break;
     default:
         break;
     }
