@@ -70,16 +70,47 @@ void TextField::setOpacity(qreal opacity) {
     }
 }
 
-void TextField::setFocus(bool focus) {
-    Q_D(const TextField);
+int TextField::leftMargin() const {
+    return this->textMargins().left();
+}
 
-    if ((d->complete) && (focus != this->hasFocus())) {
-        if (focus) {
-            this->setFocus(Qt::OtherFocusReason);
-        }
-        else {
-            this->clearFocus();
-        }
+void TextField::setLeftMargin(int margin) {
+    if (margin != this->leftMargin()) {
+        this->setTextMargins(margin, this->topMargin(), this->rightMargin(), this->bottomMargin());
+        emit marginsChanged();
+    }
+}
+
+int TextField::topMargin() const {
+    return this->textMargins().top();
+}
+
+void TextField::setTopMargin(int margin) {
+    if (margin != this->topMargin()) {
+        this->setTextMargins(this->leftMargin(), margin, this->rightMargin(), this->bottomMargin());
+        emit marginsChanged();
+    }
+}
+
+int TextField::rightMargin() const {
+    return this->textMargins().right();
+}
+
+void TextField::setRightMargin(int margin) {
+    if (margin != this->rightMargin()) {
+        this->setTextMargins(this->leftMargin(), this->topMargin(), margin, this->bottomMargin());
+        emit marginsChanged();
+    }
+}
+
+int TextField::bottomMargin() const {
+    return this->textMargins().bottom();
+}
+
+void TextField::setBottomMargin(int margin) {
+    if (margin != this->bottomMargin()) {
+        this->setTextMargins(this->leftMargin(), this->topMargin(), this->rightMargin(), margin);
+        emit marginsChanged();
     }
 }
 
@@ -124,6 +155,9 @@ void TextField::changeEvent(QEvent *event) {
     case QEvent::ParentChange:
         emit parentChanged();
         break;
+    case QEvent::EnabledChange:
+        emit enabledChanged();
+        break;
     default:
         break;
     }
@@ -166,12 +200,12 @@ void TextField::hideEvent(QHideEvent *event) {
 }
 
 void TextField::focusInEvent(QFocusEvent *event) {
-    emit visibleChanged();
+    emit focusChanged();
     QLineEdit::focusInEvent(event);
 }
 
 void TextField::focusOutEvent(QFocusEvent *event) {
-    emit visibleChanged();
+    emit focusChanged();
     QLineEdit::focusOutEvent(event);
 }
 
