@@ -20,9 +20,11 @@
 
 #include "anchors_p.h"
 #include <QWebView>
+#include <QWebPage>
 #include <QDeclarativeParserStatus>
 #include <qdeclarative.h>
 
+class QDeclarativeComponent;
 class WebHistory;
 class WebSettings;
 class WebViewPrivate;
@@ -37,9 +39,7 @@ class WebView : public QWebView, public QDeclarativeParserStatus
     Q_PROPERTY(int width READ width WRITE setFixedWidth NOTIFY widthChanged)
     Q_PROPERTY(int height READ height WRITE setFixedHeight NOTIFY heightChanged)
     Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity NOTIFY opacityChanged)
-    Q_PROPERTY(bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
-    Q_PROPERTY(QString title READ title NOTIFY titleChanged)
-    Q_PROPERTY(QUrl url READ url WRITE setUrl NOTIFY urlChanged)
+    Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
     Q_PRIVATE_PROPERTY(WebView::d_func(), Anchors* anchors READ anchors CONSTANT FINAL)
     Q_PROPERTY(AnchorLine left READ left CONSTANT FINAL)
     Q_PROPERTY(AnchorLine right READ right CONSTANT FINAL)
@@ -47,8 +47,11 @@ class WebView : public QWebView, public QDeclarativeParserStatus
     Q_PROPERTY(AnchorLine bottom READ bottom CONSTANT FINAL)
     Q_PROPERTY(AnchorLine horizontalCenter READ horizontalCenter CONSTANT FINAL)
     Q_PROPERTY(AnchorLine verticalCenter READ verticalCenter CONSTANT FINAL)
+    Q_PROPERTY(QString title READ title NOTIFY titleChanged)
+    Q_PROPERTY(QUrl url READ url WRITE setUrl NOTIFY urlChanged)
     Q_PROPERTY(QString icon READ iconSource NOTIFY iconChanged)
     Q_PROPERTY(bool textSelectionEnabled READ textSelectionEnabled WRITE setTextSelectionEnabled NOTIFY textSelectionEnabledChanged)
+    Q_PROPERTY(QWebPage::LinkDelegationPolicy linkDelegationPolicy READ linkDelegationPolicy WRITE setLinkDelegationPolicy NOTIFY linkDelegationPolicyChanged)
     Q_PROPERTY(bool moving READ moving NOTIFY movingChanged)
     Q_PROPERTY(bool atXBeginning READ atXBeginning NOTIFY contentXChanged)
     Q_PROPERTY(bool atXEnd READ atXEnd NOTIFY contentXChanged)
@@ -56,16 +59,23 @@ class WebView : public QWebView, public QDeclarativeParserStatus
     Q_PROPERTY(bool atYEnd READ atYEnd NOTIFY contentYChanged)
     Q_PROPERTY(int contentX READ contentX WRITE setContentX NOTIFY contentXChanged)
     Q_PROPERTY(int contentY READ contentY WRITE setContentY NOTIFY contentYChanged)
+    Q_PROPERTY(qreal flickDeceleration READ flickDeceleration WRITE setFlickDeceleration NOTIFY flickDecelerationChanged)
+    Q_PROPERTY(qreal maximumFlickVelocity READ maximumFlickVelocity WRITE setMaximumFlickVelocity NOTIFY maximumFlickVelocityChanged)
     Q_PROPERTY(int progress READ progress NOTIFY progressChanged)
     Q_PROPERTY(Status status READ status NOTIFY statusChanged)
+    Q_PROPERTY(QString statusText READ statusText NOTIFY statusTextChanged)
+    Q_PROPERTY(QDeclarativeComponent* newWindowComponent READ newWindowComponent WRITE setNewWindowComponent NOTIFY newWindowComponentChanged)
+    Q_PROPERTY(QWidget* newWindowParent READ newWindowParent WRITE setNewWindowParent NOTIFY newWindowParentChanged)
     Q_PRIVATE_PROPERTY(WebView::d_func(), WebHistory* history READ history CONSTANT FINAL)
     Q_PRIVATE_PROPERTY(WebView::d_func(), WebSettings* settings READ settings CONSTANT FINAL)
     Q_PRIVATE_PROPERTY(WebView::d_func(), QDeclarativeListProperty<QObject> data READ data)
     Q_PRIVATE_PROPERTY(WebView::d_func(), QDeclarativeListProperty<QWidget> children READ children)
     Q_PRIVATE_PROPERTY(WebView::d_func(), QDeclarativeListProperty<QObject> actions READ actions)
+    Q_PRIVATE_PROPERTY(WebView::d_func(), QDeclarativeListProperty<QObject> javaScriptWindowObjects READ jsObjects)
     Q_PRIVATE_PROPERTY(WebView::d_func(), bool visible READ qmlVisible WRITE setQmlVisible NOTIFY visibleChanged)
+    Q_PRIVATE_PROPERTY(WebView::d_func(), bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
 
-    Q_ENUMS(Status)
+    Q_ENUMS(Status QWebPage::LinkDelegationPolicy)
 
     Q_INTERFACES(QDeclarativeParserStatus)
 
@@ -88,8 +98,6 @@ public:
     qreal opacity() const;
     void setOpacity(qreal opacity);
 
-    void setFocus(bool focus);
-
     AnchorLine left() const;
     AnchorLine right() const;
     AnchorLine top() const;
@@ -102,6 +110,9 @@ public:
     bool textSelectionEnabled() const;
     void setTextSelectionEnabled(bool enabled);
 
+    QWebPage::LinkDelegationPolicy linkDelegationPolicy() const;
+    void setLinkDelegationPolicy(QWebPage::LinkDelegationPolicy policy);
+
     bool moving() const;
 
     bool atXBeginning() const;
@@ -126,6 +137,14 @@ public:
 
     Status status() const;
 
+    QString statusText() const;
+
+    QDeclarativeComponent* newWindowComponent() const;
+    void setNewWindowComponent(QDeclarativeComponent *component);
+
+    QWidget* newWindowParent() const;
+    void setNewWindowParent(QWidget *parent);
+
 signals:
     void parentChanged();
     void xChanged();
@@ -134,10 +153,12 @@ signals:
     void heightChanged();
     void opacityChanged();
     void visibleChanged();
+    void enabledChanged();
     void focusChanged();
     void titleChanged();
     void urlChanged();
     void textSelectionEnabledChanged();
+    void linkDelegationPolicyChanged();
     void movingChanged();
     void contentXChanged();
     void contentYChanged();
@@ -145,29 +166,39 @@ signals:
     void maximumFlickVelocityChanged();
     void progressChanged();
     void statusChanged();
+    void statusTextChanged();
+    void newWindowComponentChanged();
+    void newWindowParentChanged();
+    void linkClicked(const QUrl &link);
 
 protected:
     WebView(WebViewPrivate &dd, QWidget *parent = 0);
 
-    void changeEvent(QEvent *event);
-    void moveEvent(QMoveEvent *event);
-    void resizeEvent(QResizeEvent *event);
-    void showEvent(QShowEvent *event);
-    void hideEvent(QHideEvent *event);
-    void focusInEvent(QFocusEvent *event);
-    void focusOutEvent(QFocusEvent *event);
+    virtual QWebView* createWindow(QWebPage::WebWindowType type);
 
-    void classBegin();
-    void componentComplete();
+    virtual void changeEvent(QEvent *event);
+    virtual void moveEvent(QMoveEvent *event);
+    virtual void resizeEvent(QResizeEvent *event);
+    virtual void showEvent(QShowEvent *event);
+    virtual void hideEvent(QHideEvent *event);
+    virtual void focusInEvent(QFocusEvent *event);
+    virtual void focusOutEvent(QFocusEvent *event);
+
+    virtual void classBegin();
+    virtual void componentComplete();
 
     QScopedPointer<WebViewPrivate> d_ptr;
 
     Q_DECLARE_PRIVATE(WebView)
-    Q_DISABLE_COPY(WebView)
 
     Q_PRIVATE_SLOT(d_func(), void _q_onLoadStarted())
     Q_PRIVATE_SLOT(d_func(), void _q_onLoadFinished(bool))
     Q_PRIVATE_SLOT(d_func(), void _q_onLoadProgress(int))
+    Q_PRIVATE_SLOT(d_func(), void _q_onStatusBarMessage(QString))
+    Q_PRIVATE_SLOT(d_func(), void _q_onJavaScriptWindowObjectCleared())
+
+private:
+    Q_DISABLE_COPY(WebView)
 };
 
 QML_DECLARE_TYPE(WebView)
