@@ -108,6 +108,8 @@ public:
         kineticScroller(parent->property("kineticScroller").value<QAbstractKineticScroller*>()),
         webHistory(0),
         webSettings(0),
+        windowComponent(0),
+        windowParent(0),
         progress(0),
         status(WebView::Null)
     {
@@ -119,12 +121,16 @@ public:
 
     static void actions_append(QDeclarativeListProperty<QObject> *list, QObject *obj);
 
+    static void jsobjects_append(QDeclarativeListProperty<QObject> *list, QObject *obj);
+
     QDeclarativeListProperty<QObject> data();
 
     QDeclarativeListProperty<QWidget> children();
 
     QDeclarativeListProperty<QObject> actions();
 
+    QDeclarativeListProperty<QObject> jsObjects();
+
     WebHistory* history();
 
     WebSettings* settings();
@@ -133,6 +139,10 @@ public:
     void _q_onLoadFinished(bool ok);
     void _q_onLoadProgress(int p);
 
+    void _q_onStatusBarMessage(const QString &message);
+
+    void _q_onJavaScriptWindowObjectCleared();
+
     WebViewSelectionSuppressor *suppressor;
 
     QAbstractKineticScroller *kineticScroller;
@@ -141,10 +151,18 @@ public:
 
     WebSettings *webSettings;
 
+    QDeclarativeComponent *windowComponent;
+
+    QWidget *windowParent;
+
     int progress;
 
     WebView::Status status;
 
+    QString statusText;
+
+    QList<QObject*> jsObjectList;
+
     Q_DECLARE_PUBLIC(WebView)
 };
 
